@@ -1,4 +1,11 @@
+#!/usr/bin/env python3
+# -*- coding: utf-8 -*-
+
 """
+Written by Lucas Sinclair.
+MIT Licensed.
+Contact at www.sinclair.bio
+
 Processes and parallelism
 =========================
 
@@ -21,6 +28,11 @@ Pitfalls: all the stdouts are sent back to the parent stdout, intertwined.
 
 Alternatively, use this fork of multiprocessing:
 https://github.com/uqfoundation/multiprocess
+
+See also for exceptions:
+https://stackoverflow.com/questions/15359295/
+
+Note: This module is superseded by `p_tqdm`.
 """
 
 # Optionally switch to dill instead for better pickling #
